'use strict';

exports.__esModule = true;
exports['default'] = combineReducersWithReduxables;

var _redux = require('redux');

/**
 *
 * The only difference with Redux's `combineReducers` is that it also recognizes
 * the Reduxable instances getting its reducers.
 *
 * @returns {Function} A reducer function that invokes every reducer inside the
 * passed object, and builds a state object with the same shape.
 */

function combineReducersWithReduxables(reducers) {
  // TODO: check for Reduxable inhetirance properly
  //       Don't know why `reducer.constructor.prototype instanceof Reduxable` is not working
  var newReducers = {};
  Object.keys(reducers).forEach(function (key) {
    var reducer = reducers[key];
    if (typeof reducer === 'function') {
      newReducers[key] = reducer;
    } else {
      newReducers[key] = reducer.reduce;

      if (reducer._setScope) {
        reducer._setScope(key);
      }
    }
  });

  return (0, _redux.combineReducers)(newReducers);
}